// SPDX-License-Identifier: LGPL-2.1-or-later
/*
 * This file is part of libnvme.
 * Copyright (c) 2020 Western Digital Corporation or its affiliates.
 *
 * Authors: Keith Busch <keith.busch@wdc.com>
 * 	    Chaitanya Kulkarni <chaitanya.kulkarni@wdc.com>
 */

#ifndef _LIBNVME_H
#define _LIBNVME_H

#ifdef __cplusplus
extern "C" {
#endif

#include <nvme/types.h>
#include <nvme/linux.h>
#include <nvme/ioctl.h>
#include <nvme/nbft.h>
#include <nvme/fabrics.h>
#include <nvme/filters.h>
#include <nvme/tree.h>
#include <nvme/util.h>
#include <nvme/log.h>

#ifdef __cplusplus
}
#endif

#endif /* _LIBNVME_H */
